@@ -7,9 +7,11 @@ TODO:
 
 * Is it reasonable, that many functions match the exception lazily?
   Or is lazy decoupling an operation that shall always be done explicitly?
+
 * Is the Null type appropriate anywhere?
   Should it be better a Monoid type with mempty?
   Shall Monoid.mempty be the default, or functions with explicit default values?
+
 * Shall we replace Monad constraint by Functor constraint,
   where we only need liftM?
 -}
@@ -234,6 +236,21 @@ mapExceptional f g ~(Exceptional e a) = Exceptional (fmap f e) (g a)
 
 {-
 fmap (f.g) = fmap f . fmap g
+
+FIXME:
+The law
+  fmap id = id
+requires that we match the constructor strictly.
+
+Strict matching
+  fmap id undefined = undefined = id undefined
+
+Lazy matching
+  fmap id undefined = Exceptional undefined undefined
+      /= undefined = id undefined
+
+This was pointed out by kahl@cas.mcmaster.ca in libraries@haskell.org, 2011-01-22.
+However, I think we rely a lot on the lazy matching in http-monad and parallelweb.
 -}
 instance Functor (Exceptional e) where
    fmap f ~(Exceptional e a) = Exceptional e (f a)
